Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(213)

Unified Diff: webkit/support/platform_support_android.cc

Issue 11416182: Allow WebKit performance tests to be available for Android devices (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/support/platform_support_android.cc
diff --git a/webkit/support/platform_support_android.cc b/webkit/support/platform_support_android.cc
index 581f230de5a548a0b262cca9747cd7f30732c1c2..f6bf077361e80c3d6b352b6e780d0b39d960291b 100644
--- a/webkit/support/platform_support_android.cc
+++ b/webkit/support/platform_support_android.cc
@@ -66,15 +66,18 @@ void AfterInitialize(bool unit_test_mode) {
// We enable file-over-http to bridge the file protocol to http protocol
// in here, which can
// (1) run the layout tests on android target device, but never need to
// push the test files and corresponding resources to device, which saves
// huge running time.
// (2) still run non-http layout (tests not under LayoutTests/http) tests
// via file protocol without breaking test environment / convention of webkit
// layout tests, which are followed by current all webkit ports.
SimpleResourceLoaderBridge::AllowFileOverHTTP(
"third_party/WebKit/LayoutTests/",
GURL("http://127.0.0.1:8000/all-tests/"));
+ SimpleResourceLoaderBridge::AllowFileOverHTTP(
+ "third_party/WebKit/PerformanceTests/",
+ GURL("http://127.0.0.1:8000/all-perf-tests/"));
}
void BeforeShutdown() {
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -66,15 +66,18 @@ void AfterInitialize(bool unit_test_mode) {
// We enable file-over-http to bridge the file protocol to http protocol
// in here, which can
- // (1) run the layout tests on android target device, but never need to
- // push the test files and corresponding resources to device, which saves
- // huge running time.
+ // (1) run the layout and performance tests on android target device, but
+ // never need to push the test files and corresponding resources to device,
+ // which saves huge running time.
// (2) still run non-http layout (tests not under LayoutTests/http) tests
// via file protocol without breaking test environment / convention of webkit

Powered by Google App Engine
This is Rietveld 408576698